# Copyright (c) 2013, 2014 Dave Love, Liverpool University
# The licence for this file is as for the package itself.

# Fixme: Use packaged samtools (0.1.19, c.f. bundled 0.1.18)?

Name: tophat
Version: 2.1.1
Release: 2%{?dist}
Summary: Fast splice junction mapper for RNA-Seq reads       
Group: Engineering and Scientific
# The source contains copies of the Artistic licence and GPL, but they
# don't actually seem to apply to anything.  Since it uses seqan, it
# inherits BSD with advertising from that.
License: Boost and BSD with advertising and MIT
URL: http://ccb.jhu.edu/software/tophat/index.shtml
Source0: http://ccb.jhu.edu/software/tophat/downloads/%{name}-%{version}.tar.gz
BuildRequires: samtools-devel, zlib-devel, python-devel
%if 0%{?fedora}
BuildRequires: seqan-devel >= 1.4
%endif
BuildRequires: boost-devel boost-thread
# Invoked via /bin/env and not picked up by dependency checking.
# Fixme:  Is python always available?
Requires: python
# Invoked by the script.  Fixme: Are they always available?
Requires: xz, bzip2
# Specific version with distinct name
Provides: bundled(samtools)
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root


%description
TopHat is a fast splice junction mapper for RNA-Seq reads. It aligns RNA-Seq
reads to mammalian-sized genomes using the ultra high-throughput short read
aligner Bowtie, and then analyzes the mapping results to identify splice
junctions between exons.

TopHat is a collaborative effort between the Institute of Genetic Medicine at
Johns Hopkins University, the Department of Mathematics at the University of
California, Berkeley, and the Department of Stem Cell and Regenerative Biology
at Harvard University.


%prep
%setup -q
# samtools installs /usr/inlude/samtools/bam.h, but tophat looks for
# <bam/bam.h>.  This and the configure command avoid a patch.
# ln -sf /usr/include/samtools bam

%build
# Why doesn't _hardened_build 0 work?
%global _hardened_cflags %nil
%global _hardened_ldflags %nil
# gnu98 to work on recent Fedora
%global optflags %{optflags} -O3 -std=gnu++98
%configure --with-boost-thread=-lboost_thread-mt CPPFLAGS=-I$(pwd)
make				# not SMP-safe

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%python_sitelib
mv $RPM_BUILD_ROOT%_bindir/{intervaltree,sortedcontainers} $RPM_BUILD_ROOT%python_sitelib
chmod -x $RPM_BUILD_ROOT%python_sitelib/*/*.py


%clean
rm -rf $RPM_BUILD_ROOT

%{!?_licensedir:%global license %doc}
%files
%{_bindir}/*
%python_sitelib/*
%license LICENSE
# NEWS is old
%doc README AUTHORS THANKS

# Done without finding Adam Huffman's previous effort :-(
# https://bugzilla.redhat.com/show_bug.cgi?id=708402

%changelog
* Fri May 13 2016 Dave Love <loveshack@fedoraproject.org> - 2.1.1-2
- Fix build on recent Fedora

* Mon May  9 2016 Dave Love <loveshack@fedoraproject.org> - 2.1.1-1
- New version
- Use %%license
- Move python libs to sitelib
- Use bundled seqan on EPEL; drop patch
- Restore -O3
- Use fPIC to avoid failure with f23+

* Thu Jan 14 2016 Dave Love <loveshack@fedoraproject.org> - 2.1.0-1
- New version

* Mon Mar 30 2015 Dave Love <d.love@liverpool.ac.uk> - 2.0.14-1
- New version
- BR boost148-devel on el6
- Require python, bzip2, xz

* Wed Jan 28 2015 Dave Love <d.love@liverpool.ac.uk> - 2.0.13-1
- New version
- Modify configure invocation

* Mon Dec  1 2014 Dave Love <d.love@liverpool.ac.uk> - 2.0.12-1
- New version

* Wed Jul 30 2014 Dave Love <d.love@liverpool.ac.uk> - 2.0.11-3
- Build against packaged seqan, with Debian patch

* Tue Jun 24 2014 Dave Love <d.love@liverpool.ac.uk> - 2.0.11-2
- BR samtools-devel, not samtools
- BR zlib-devel

* Wed Jun  4 2014 Dave Love <d.love@liverpool.ac.uk> - 2.0.11-1
- Update to 2.0.11
- Add AUTHORS, THANKS

* Wed Nov 20 2013 Dave Love <d.love@liverpool.ac.uk> - 2.0.10-1
- Update to 2.0.10
- Fix finding bam.h

* Tue Jul  2 2013 Dave Love <d.love@liverpool.ac.uk> - 2.0.9-1
- Initial packaging
